# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from scale_gp_beta import SGPClient, AsyncSGPClient
from scale_gp_beta.types import (
    Evaluation,
    EvaluationSchemaResponse,
)
from scale_gp_beta.pagination import SyncCursorPage, AsyncCursorPage

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestEvaluations:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create_overload_1(self, client: SGPClient) -> None:
        evaluation = client.evaluations.create(
            data=[{"foo": "bar"}],
            name="name",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_method_create_with_all_params_overload_1(self, client: SGPClient) -> None:
        evaluation = client.evaluations.create(
            data=[{"foo": "bar"}],
            name="name",
            description="description",
            files=[{"foo": "string"}],
            metadata={"foo": "bar"},
            tags=["string"],
            tasks=[
                {
                    "configuration": {
                        "messages": [{"foo": "bar"}],
                        "model": "model",
                        "audio": {"foo": "bar"},
                        "frequency_penalty": 0,
                        "function_call": {"foo": "bar"},
                        "functions": [{"foo": "bar"}],
                        "logit_bias": {"foo": 0},
                        "logprobs": True,
                        "max_completion_tokens": 0,
                        "max_tokens": 0,
                        "metadata": {"foo": "string"},
                        "modalities": ["string"],
                        "n": 0,
                        "parallel_tool_calls": True,
                        "prediction": {"foo": "bar"},
                        "presence_penalty": 0,
                        "reasoning_effort": "reasoning_effort",
                        "response_format": {"foo": "bar"},
                        "seed": 0,
                        "stop": "stop",
                        "store": True,
                        "temperature": 0,
                        "tool_choice": "tool_choice",
                        "tools": [{"foo": "bar"}],
                        "top_k": 0,
                        "top_logprobs": 0,
                        "top_p": 0,
                    },
                    "alias": "alias",
                    "task_type": "chat_completion",
                }
            ],
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_raw_response_create_overload_1(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.create(
            data=[{"foo": "bar"}],
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_streaming_response_create_overload_1(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.create(
            data=[{"foo": "bar"}],
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_create_overload_2(self, client: SGPClient) -> None:
        evaluation = client.evaluations.create(
            dataset_id="dataset_id",
            name="name",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_method_create_with_all_params_overload_2(self, client: SGPClient) -> None:
        evaluation = client.evaluations.create(
            dataset_id="dataset_id",
            name="name",
            data=[{"dataset_item_id": "dataset_item_id"}],
            description="description",
            metadata={"foo": "bar"},
            tags=["string"],
            tasks=[
                {
                    "configuration": {
                        "messages": [{"foo": "bar"}],
                        "model": "model",
                        "audio": {"foo": "bar"},
                        "frequency_penalty": 0,
                        "function_call": {"foo": "bar"},
                        "functions": [{"foo": "bar"}],
                        "logit_bias": {"foo": 0},
                        "logprobs": True,
                        "max_completion_tokens": 0,
                        "max_tokens": 0,
                        "metadata": {"foo": "string"},
                        "modalities": ["string"],
                        "n": 0,
                        "parallel_tool_calls": True,
                        "prediction": {"foo": "bar"},
                        "presence_penalty": 0,
                        "reasoning_effort": "reasoning_effort",
                        "response_format": {"foo": "bar"},
                        "seed": 0,
                        "stop": "stop",
                        "store": True,
                        "temperature": 0,
                        "tool_choice": "tool_choice",
                        "tools": [{"foo": "bar"}],
                        "top_k": 0,
                        "top_logprobs": 0,
                        "top_p": 0,
                    },
                    "alias": "alias",
                    "task_type": "chat_completion",
                }
            ],
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_raw_response_create_overload_2(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.create(
            dataset_id="dataset_id",
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_streaming_response_create_overload_2(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.create(
            dataset_id="dataset_id",
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_create_overload_3(self, client: SGPClient) -> None:
        evaluation = client.evaluations.create(
            data=[{"foo": "bar"}],
            dataset={"name": "name"},
            name="name",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_method_create_with_all_params_overload_3(self, client: SGPClient) -> None:
        evaluation = client.evaluations.create(
            data=[{"foo": "bar"}],
            dataset={
                "name": "name",
                "description": "description",
                "keys": ["string"],
                "tags": ["string"],
            },
            name="name",
            description="description",
            files=[{"foo": "string"}],
            metadata={"foo": "bar"},
            tags=["string"],
            tasks=[
                {
                    "configuration": {
                        "messages": [{"foo": "bar"}],
                        "model": "model",
                        "audio": {"foo": "bar"},
                        "frequency_penalty": 0,
                        "function_call": {"foo": "bar"},
                        "functions": [{"foo": "bar"}],
                        "logit_bias": {"foo": 0},
                        "logprobs": True,
                        "max_completion_tokens": 0,
                        "max_tokens": 0,
                        "metadata": {"foo": "string"},
                        "modalities": ["string"],
                        "n": 0,
                        "parallel_tool_calls": True,
                        "prediction": {"foo": "bar"},
                        "presence_penalty": 0,
                        "reasoning_effort": "reasoning_effort",
                        "response_format": {"foo": "bar"},
                        "seed": 0,
                        "stop": "stop",
                        "store": True,
                        "temperature": 0,
                        "tool_choice": "tool_choice",
                        "tools": [{"foo": "bar"}],
                        "top_k": 0,
                        "top_logprobs": 0,
                        "top_p": 0,
                    },
                    "alias": "alias",
                    "task_type": "chat_completion",
                }
            ],
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_raw_response_create_overload_3(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.create(
            data=[{"foo": "bar"}],
            dataset={"name": "name"},
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_streaming_response_create_overload_3(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.create(
            data=[{"foo": "bar"}],
            dataset={"name": "name"},
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: SGPClient) -> None:
        evaluation = client.evaluations.retrieve(
            evaluation_id="evaluation_id",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_method_retrieve_with_all_params(self, client: SGPClient) -> None:
        evaluation = client.evaluations.retrieve(
            evaluation_id="evaluation_id",
            include_archived=True,
            views=["tasks"],
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.retrieve(
            evaluation_id="evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.retrieve(
            evaluation_id="evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            client.evaluations.with_raw_response.retrieve(
                evaluation_id="",
            )

    @parametrize
    def test_method_update_overload_1(self, client: SGPClient) -> None:
        evaluation = client.evaluations.update(
            evaluation_id="evaluation_id",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_method_update_with_all_params_overload_1(self, client: SGPClient) -> None:
        evaluation = client.evaluations.update(
            evaluation_id="evaluation_id",
            description="description",
            name="name",
            tags=["string"],
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_raw_response_update_overload_1(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.update(
            evaluation_id="evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_streaming_response_update_overload_1(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.update(
            evaluation_id="evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update_overload_1(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            client.evaluations.with_raw_response.update(
                evaluation_id="",
            )

    @parametrize
    def test_method_update_overload_2(self, client: SGPClient) -> None:
        evaluation = client.evaluations.update(
            evaluation_id="evaluation_id",
            restore=True,
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_raw_response_update_overload_2(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.update(
            evaluation_id="evaluation_id",
            restore=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_streaming_response_update_overload_2(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.update(
            evaluation_id="evaluation_id",
            restore=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update_overload_2(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            client.evaluations.with_raw_response.update(
                evaluation_id="",
                restore=True,
            )

    @parametrize
    def test_method_list(self, client: SGPClient) -> None:
        evaluation = client.evaluations.list()
        assert_matches_type(SyncCursorPage[Evaluation], evaluation, path=["response"])

    @parametrize
    def test_method_list_with_all_params(self, client: SGPClient) -> None:
        evaluation = client.evaluations.list(
            ending_before="ending_before",
            include_archived=True,
            limit=1,
            name="name",
            sort_by="sort_by",
            sort_order="asc",
            starting_after="starting_after",
            tags=["string"],
            views=["tasks"],
        )
        assert_matches_type(SyncCursorPage[Evaluation], evaluation, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(SyncCursorPage[Evaluation], evaluation, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(SyncCursorPage[Evaluation], evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete(self, client: SGPClient) -> None:
        evaluation = client.evaluations.delete(
            "evaluation_id",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_raw_response_delete(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.delete(
            "evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    def test_streaming_response_delete(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.delete(
            "evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            client.evaluations.with_raw_response.delete(
                "",
            )

    @parametrize
    def test_method_retrieve_schema(self, client: SGPClient) -> None:
        evaluation = client.evaluations.retrieve_schema(
            evaluation_id="evaluation_id",
        )
        assert_matches_type(EvaluationSchemaResponse, evaluation, path=["response"])

    @parametrize
    def test_method_retrieve_schema_with_all_params(self, client: SGPClient) -> None:
        evaluation = client.evaluations.retrieve_schema(
            evaluation_id="evaluation_id",
            include_archived=True,
        )
        assert_matches_type(EvaluationSchemaResponse, evaluation, path=["response"])

    @parametrize
    def test_raw_response_retrieve_schema(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.retrieve_schema(
            evaluation_id="evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(EvaluationSchemaResponse, evaluation, path=["response"])

    @parametrize
    def test_streaming_response_retrieve_schema(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.retrieve_schema(
            evaluation_id="evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(EvaluationSchemaResponse, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve_schema(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            client.evaluations.with_raw_response.retrieve_schema(
                evaluation_id="",
            )


class TestAsyncEvaluations:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create_overload_1(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.create(
            data=[{"foo": "bar"}],
            name="name",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_method_create_with_all_params_overload_1(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.create(
            data=[{"foo": "bar"}],
            name="name",
            description="description",
            files=[{"foo": "string"}],
            metadata={"foo": "bar"},
            tags=["string"],
            tasks=[
                {
                    "configuration": {
                        "messages": [{"foo": "bar"}],
                        "model": "model",
                        "audio": {"foo": "bar"},
                        "frequency_penalty": 0,
                        "function_call": {"foo": "bar"},
                        "functions": [{"foo": "bar"}],
                        "logit_bias": {"foo": 0},
                        "logprobs": True,
                        "max_completion_tokens": 0,
                        "max_tokens": 0,
                        "metadata": {"foo": "string"},
                        "modalities": ["string"],
                        "n": 0,
                        "parallel_tool_calls": True,
                        "prediction": {"foo": "bar"},
                        "presence_penalty": 0,
                        "reasoning_effort": "reasoning_effort",
                        "response_format": {"foo": "bar"},
                        "seed": 0,
                        "stop": "stop",
                        "store": True,
                        "temperature": 0,
                        "tool_choice": "tool_choice",
                        "tools": [{"foo": "bar"}],
                        "top_k": 0,
                        "top_logprobs": 0,
                        "top_p": 0,
                    },
                    "alias": "alias",
                    "task_type": "chat_completion",
                }
            ],
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_raw_response_create_overload_1(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.create(
            data=[{"foo": "bar"}],
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_streaming_response_create_overload_1(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.create(
            data=[{"foo": "bar"}],
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_create_overload_2(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.create(
            dataset_id="dataset_id",
            name="name",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_method_create_with_all_params_overload_2(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.create(
            dataset_id="dataset_id",
            name="name",
            data=[{"dataset_item_id": "dataset_item_id"}],
            description="description",
            metadata={"foo": "bar"},
            tags=["string"],
            tasks=[
                {
                    "configuration": {
                        "messages": [{"foo": "bar"}],
                        "model": "model",
                        "audio": {"foo": "bar"},
                        "frequency_penalty": 0,
                        "function_call": {"foo": "bar"},
                        "functions": [{"foo": "bar"}],
                        "logit_bias": {"foo": 0},
                        "logprobs": True,
                        "max_completion_tokens": 0,
                        "max_tokens": 0,
                        "metadata": {"foo": "string"},
                        "modalities": ["string"],
                        "n": 0,
                        "parallel_tool_calls": True,
                        "prediction": {"foo": "bar"},
                        "presence_penalty": 0,
                        "reasoning_effort": "reasoning_effort",
                        "response_format": {"foo": "bar"},
                        "seed": 0,
                        "stop": "stop",
                        "store": True,
                        "temperature": 0,
                        "tool_choice": "tool_choice",
                        "tools": [{"foo": "bar"}],
                        "top_k": 0,
                        "top_logprobs": 0,
                        "top_p": 0,
                    },
                    "alias": "alias",
                    "task_type": "chat_completion",
                }
            ],
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_raw_response_create_overload_2(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.create(
            dataset_id="dataset_id",
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_streaming_response_create_overload_2(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.create(
            dataset_id="dataset_id",
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_create_overload_3(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.create(
            data=[{"foo": "bar"}],
            dataset={"name": "name"},
            name="name",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_method_create_with_all_params_overload_3(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.create(
            data=[{"foo": "bar"}],
            dataset={
                "name": "name",
                "description": "description",
                "keys": ["string"],
                "tags": ["string"],
            },
            name="name",
            description="description",
            files=[{"foo": "string"}],
            metadata={"foo": "bar"},
            tags=["string"],
            tasks=[
                {
                    "configuration": {
                        "messages": [{"foo": "bar"}],
                        "model": "model",
                        "audio": {"foo": "bar"},
                        "frequency_penalty": 0,
                        "function_call": {"foo": "bar"},
                        "functions": [{"foo": "bar"}],
                        "logit_bias": {"foo": 0},
                        "logprobs": True,
                        "max_completion_tokens": 0,
                        "max_tokens": 0,
                        "metadata": {"foo": "string"},
                        "modalities": ["string"],
                        "n": 0,
                        "parallel_tool_calls": True,
                        "prediction": {"foo": "bar"},
                        "presence_penalty": 0,
                        "reasoning_effort": "reasoning_effort",
                        "response_format": {"foo": "bar"},
                        "seed": 0,
                        "stop": "stop",
                        "store": True,
                        "temperature": 0,
                        "tool_choice": "tool_choice",
                        "tools": [{"foo": "bar"}],
                        "top_k": 0,
                        "top_logprobs": 0,
                        "top_p": 0,
                    },
                    "alias": "alias",
                    "task_type": "chat_completion",
                }
            ],
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_raw_response_create_overload_3(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.create(
            data=[{"foo": "bar"}],
            dataset={"name": "name"},
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_streaming_response_create_overload_3(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.create(
            data=[{"foo": "bar"}],
            dataset={"name": "name"},
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.retrieve(
            evaluation_id="evaluation_id",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_method_retrieve_with_all_params(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.retrieve(
            evaluation_id="evaluation_id",
            include_archived=True,
            views=["tasks"],
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.retrieve(
            evaluation_id="evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.retrieve(
            evaluation_id="evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            await async_client.evaluations.with_raw_response.retrieve(
                evaluation_id="",
            )

    @parametrize
    async def test_method_update_overload_1(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.update(
            evaluation_id="evaluation_id",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_method_update_with_all_params_overload_1(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.update(
            evaluation_id="evaluation_id",
            description="description",
            name="name",
            tags=["string"],
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_raw_response_update_overload_1(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.update(
            evaluation_id="evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_streaming_response_update_overload_1(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.update(
            evaluation_id="evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update_overload_1(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            await async_client.evaluations.with_raw_response.update(
                evaluation_id="",
            )

    @parametrize
    async def test_method_update_overload_2(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.update(
            evaluation_id="evaluation_id",
            restore=True,
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_raw_response_update_overload_2(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.update(
            evaluation_id="evaluation_id",
            restore=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_streaming_response_update_overload_2(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.update(
            evaluation_id="evaluation_id",
            restore=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update_overload_2(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            await async_client.evaluations.with_raw_response.update(
                evaluation_id="",
                restore=True,
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.list()
        assert_matches_type(AsyncCursorPage[Evaluation], evaluation, path=["response"])

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.list(
            ending_before="ending_before",
            include_archived=True,
            limit=1,
            name="name",
            sort_by="sort_by",
            sort_order="asc",
            starting_after="starting_after",
            tags=["string"],
            views=["tasks"],
        )
        assert_matches_type(AsyncCursorPage[Evaluation], evaluation, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(AsyncCursorPage[Evaluation], evaluation, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(AsyncCursorPage[Evaluation], evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.delete(
            "evaluation_id",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.delete(
            "evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.delete(
            "evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            await async_client.evaluations.with_raw_response.delete(
                "",
            )

    @parametrize
    async def test_method_retrieve_schema(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.retrieve_schema(
            evaluation_id="evaluation_id",
        )
        assert_matches_type(EvaluationSchemaResponse, evaluation, path=["response"])

    @parametrize
    async def test_method_retrieve_schema_with_all_params(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.retrieve_schema(
            evaluation_id="evaluation_id",
            include_archived=True,
        )
        assert_matches_type(EvaluationSchemaResponse, evaluation, path=["response"])

    @parametrize
    async def test_raw_response_retrieve_schema(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.retrieve_schema(
            evaluation_id="evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(EvaluationSchemaResponse, evaluation, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve_schema(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.retrieve_schema(
            evaluation_id="evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(EvaluationSchemaResponse, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve_schema(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            await async_client.evaluations.with_raw_response.retrieve_schema(
                evaluation_id="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from .._types import SequenceNotStr

__all__ = ["EvaluationDashboardCreateParams"]


class EvaluationDashboardCreateParams(TypedDict, total=False):
    name: Required[str]
    """Dashboard name"""

    description: str
    """Optional description of the dashboard"""

    evaluation_group_id: str
    """Evaluation group ID (XOR with evaluation_id)"""

    evaluation_id: str
    """Evaluation ID (XOR with evaluation_group_id)"""

    tags: SequenceNotStr[str]
    """The tags associated with the entity"""

    template_dashboard_id: str
    """Optional dashboard ID to use as template. Copies widget_order from template."""

    widget_order: SequenceNotStr[str]
    """Ordered array of widget IDs to display on this dashboard"""



# The following `type: ignore` is necessary because this file provides an optional
# integration for the 'openai-agents' library. The linter will report missing
# imports if the library isn't installed in the development environment, but the
# code handles this gracefully at runtime with a try/except block.
# type: ignore
import logging
from typing import TYPE_CHECKING, Any, Dict, Optional

from scale_gp_beta.lib.tracing.span import BaseSpan
from scale_gp_beta.lib.tracing.tracing import create_span, flush_queue, create_trace, tracing_queue_manager
from scale_gp_beta.lib.tracing.trace_queue_manager import TraceQueueManager

from .utils import sgp_span_name, parse_metadata, extract_response, parse_input_output
from .openai_span_type_map import openai_span_type_map

log: logging.Logger = logging.getLogger(__name__)

try:
    from agents.tracing import (
        Span as OpenAISpan,
        Trace as OpenAITrace,
        SpanData as OpenAISpanData,
        ResponseSpanData as OpenAIResponseSpanData,
        TracingProcessor,
    )

    _openai_agents_installed = True
except ImportError:
    _openai_agents_installed = False
    TracingProcessor = object
    class _Fallback:
        pass

    OpenAISpan = _Fallback
    OpenAITrace = _Fallback
    OpenAISpanData = _Fallback
    OpenAIResponseSpanData = _Fallback

    if TYPE_CHECKING:
        OpenAISpan = Any
        OpenAITrace = Any
        OpenAISpanData = Any
        OpenAIResponseSpanData = Any


class OpenAITracingSGPProcessor(TracingProcessor):
    """
    An SGP tracing processor that integrates with OpenAI Agents SDK.

    This processor requires the 'openai-agents' library to be installed.
    It will raise an ImportError on initialization if the library is not found.
    """

    def __init__(
            self,
            *,
            queue_manager: Optional[TraceQueueManager] = None,
    ):
        """
        Initializes the processor.

        Args:
            queue_manager: An optional custom trace queue manager.

        Raises:
            ImportError: If the 'openai-agents' package is not installed.
        """
        # This runtime check is the gatekeeper. If 'openai-agents' isn't
        # installed, no instance of this class can be created.
        if not _openai_agents_installed:
            raise ImportError(
                "The 'openai-agents' package is required to use the OpenAITracingSGPProcessor. "
                "Please install it with: pip install 'openai-agents'"
            )

        self._queue_manager = queue_manager or tracing_queue_manager()
        self._spans: Dict[str, BaseSpan] = {}

    def on_trace_start(self, openai_trace: "OpenAITrace") -> None:
        sgp_trace = create_trace(
            name=openai_trace.name or "Agent Workflow",
            span_type="AGENT_WORKFLOW",
            group_id=openai_trace.group_id,
            trace_id=openai_trace.trace_id,
            metadata={"openai_metadata": openai_trace.metadata or {}},
        )
        sgp_trace.start()
        self._spans[openai_trace.trace_id] = sgp_trace.root_span

    def on_trace_end(self, openai_trace: "OpenAITrace") -> None:
        root_span = self._spans.pop(openai_trace.trace_id, None)
        if root_span is None:
            log.warning(f"No root span found for trace_id: {openai_trace.trace_id}")
            return
        root_span.end()

    def on_span_start(self, openai_span: "OpenAISpan") -> None:
        _spans_key = openai_span.parent_id or openai_span.trace_id
        parent_span = self._spans.get(_spans_key)
        span_data = openai_span.span_data

        if not parent_span:
            log.warning(f"No parent span found for span_id: {openai_span.span_id}")
            return

        name = sgp_span_name(openai_span)
        sgp_span_type = openai_span_type_map(span_data.type if span_data else None)

        new_span = create_span(
            name=name,
            span_type=sgp_span_type,
            span_id=openai_span.span_id,
            trace_id=parent_span.trace_id,
            parent_id=parent_span.span_id,
        )
        new_span.start()
        self._spans[openai_span.span_id] = new_span

    def on_span_end(self, openai_span: "OpenAISpan") -> None:
        sgp_span = self._spans.pop(openai_span.span_id, None)
        if sgp_span is None:
            log.warning(f"No existing span found for span_id: {openai_span.span_id}")
            return

        # special case response type, if there are more like this we should change arch to support this
        if isinstance(openai_span.span_data, OpenAIResponseSpanData):
            response = extract_response(openai_span)
            sgp_span.input = {"input": openai_span.span_data.input}
            sgp_span.output = {"output": response.get("output", None) if response else None }
        else:
            sgp_span.output = parse_input_output(openai_span, "output")
            sgp_span.input = parse_input_output(openai_span, "input")

        sgp_span.metadata = parse_metadata(openai_span)

        if openai_span.error:
            sgp_span.set_error(error_message=str(openai_span.error))
        sgp_span.end()

    def shutdown(self) -> None:
        self._queue_manager.shutdown()

    def force_flush(self) -> None:
        flush_queue()



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal

import httpx

from ...types import (
    evaluation_dashboard_list_params,
    evaluation_dashboard_create_params,
    evaluation_dashboard_update_params,
    evaluation_dashboard_retrieve_params,
)
from .widgets import (
    WidgetsResource,
    AsyncWidgetsResource,
    WidgetsResourceWithRawResponse,
    AsyncWidgetsResourceWithRawResponse,
    WidgetsResourceWithStreamingResponse,
    AsyncWidgetsResourceWithStreamingResponse,
)
from ..._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...pagination import SyncCursorPage, AsyncCursorPage
from ..._base_client import AsyncPaginator, make_request_options
from ...types.evaluation_dashboard import EvaluationDashboard

__all__ = ["EvaluationDashboardsResource", "AsyncEvaluationDashboardsResource"]


class EvaluationDashboardsResource(SyncAPIResource):
    @cached_property
    def widgets(self) -> WidgetsResource:
        return WidgetsResource(self._client)

    @cached_property
    def with_raw_response(self) -> EvaluationDashboardsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#accessing-raw-response-data-eg-headers
        """
        return EvaluationDashboardsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EvaluationDashboardsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#with_streaming_response
        """
        return EvaluationDashboardsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str,
        description: str | Omit = omit,
        evaluation_group_id: str | Omit = omit,
        evaluation_id: str | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        template_dashboard_id: str | Omit = omit,
        widget_order: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluationDashboard:
        """
        Create a new evaluation dashboard for an evaluation or evaluation group

        Args:
          name: Dashboard name

          description: Optional description of the dashboard

          evaluation_group_id: Evaluation group ID (XOR with evaluation_id)

          evaluation_id: Evaluation ID (XOR with evaluation_group_id)

          tags: The tags associated with the entity

          template_dashboard_id: Optional dashboard ID to use as template. Copies widget_order from template.

          widget_order: Ordered array of widget IDs to display on this dashboard

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v5/evaluation-dashboards",
            body=maybe_transform(
                {
                    "name": name,
                    "description": description,
                    "evaluation_group_id": evaluation_group_id,
                    "evaluation_id": evaluation_id,
                    "tags": tags,
                    "template_dashboard_id": template_dashboard_id,
                    "widget_order": widget_order,
                },
                evaluation_dashboard_create_params.EvaluationDashboardCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationDashboard,
        )

    def retrieve(
        self,
        dashboard_id: str,
        *,
        include_archived: bool | Omit = omit,
        views: List[Literal["widgets", "widget_results"]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluationDashboard:
        """
        Get a single evaluation dashboard by ID

        Args:
          views: Optional relationships to include: 'widgets', 'widget_results'

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dashboard_id:
            raise ValueError(f"Expected a non-empty value for `dashboard_id` but received {dashboard_id!r}")
        return self._get(
            f"/v5/evaluation-dashboards/{dashboard_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "include_archived": include_archived,
                        "views": views,
                    },
                    evaluation_dashboard_retrieve_params.EvaluationDashboardRetrieveParams,
                ),
            ),
            cast_to=EvaluationDashboard,
        )

    def update(
        self,
        dashboard_id: str,
        *,
        description: str | Omit = omit,
        name: str | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        widget_order: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluationDashboard:
        """
        Partially update dashboard metadata (name, description, widget_order)

        Args:
          description: Dashboard description

          name: Dashboard name

          tags: The tags associated with the entity

          widget_order: Ordered array of widget IDs (for reordering widgets)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dashboard_id:
            raise ValueError(f"Expected a non-empty value for `dashboard_id` but received {dashboard_id!r}")
        return self._patch(
            f"/v5/evaluation-dashboards/{dashboard_id}",
            body=maybe_transform(
                {
                    "description": description,
                    "name": name,
                    "tags": tags,
                    "widget_order": widget_order,
                },
                evaluation_dashboard_update_params.EvaluationDashboardUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationDashboard,
        )

    def list(
        self,
        *,
        created_by_ids: SequenceNotStr[str] | Omit = omit,
        ending_before: str | Omit = omit,
        evaluation_group_id: str | Omit = omit,
        evaluation_id: str | Omit = omit,
        include_archived: bool | Omit = omit,
        limit: int | Omit = omit,
        search: str | Omit = omit,
        sort_by: str | Omit = omit,
        sort_order: Literal["asc", "desc"] | Omit = omit,
        starting_after: str | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncCursorPage[EvaluationDashboard]:
        """
        List dashboards filtered by evaluation_id, evaluation_group_id, tags, creators,
        or search

        Args:
          created_by_ids: Filter by creator user IDs

          search: Search in name and tags

          tags: Filter by tags (case-insensitive)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v5/evaluation-dashboards",
            page=SyncCursorPage[EvaluationDashboard],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "created_by_ids": created_by_ids,
                        "ending_before": ending_before,
                        "evaluation_group_id": evaluation_group_id,
                        "evaluation_id": evaluation_id,
                        "include_archived": include_archived,
                        "limit": limit,
                        "search": search,
                        "sort_by": sort_by,
                        "sort_order": sort_order,
                        "starting_after": starting_after,
                        "tags": tags,
                    },
                    evaluation_dashboard_list_params.EvaluationDashboardListParams,
                ),
            ),
            model=EvaluationDashboard,
        )

    def delete(
        self,
        dashboard_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluationDashboard:
        """
        Soft delete an evaluation dashboard

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dashboard_id:
            raise ValueError(f"Expected a non-empty value for `dashboard_id` but received {dashboard_id!r}")
        return self._delete(
            f"/v5/evaluation-dashboards/{dashboard_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationDashboard,
        )


class AsyncEvaluationDashboardsResource(AsyncAPIResource):
    @cached_property
    def widgets(self) -> AsyncWidgetsResource:
        return AsyncWidgetsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncEvaluationDashboardsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#accessing-raw-response-data-eg-headers
        """
        return AsyncEvaluationDashboardsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEvaluationDashboardsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#with_streaming_response
        """
        return AsyncEvaluationDashboardsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str,
        description: str | Omit = omit,
        evaluation_group_id: str | Omit = omit,
        evaluation_id: str | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        template_dashboard_id: str | Omit = omit,
        widget_order: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluationDashboard:
        """
        Create a new evaluation dashboard for an evaluation or evaluation group

        Args:
          name: Dashboard name

          description: Optional description of the dashboard

          evaluation_group_id: Evaluation group ID (XOR with evaluation_id)

          evaluation_id: Evaluation ID (XOR with evaluation_group_id)

          tags: The tags associated with the entity

          template_dashboard_id: Optional dashboard ID to use as template. Copies widget_order from template.

          widget_order: Ordered array of widget IDs to display on this dashboard

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v5/evaluation-dashboards",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "description": description,
                    "evaluation_group_id": evaluation_group_id,
                    "evaluation_id": evaluation_id,
                    "tags": tags,
                    "template_dashboard_id": template_dashboard_id,
                    "widget_order": widget_order,
                },
                evaluation_dashboard_create_params.EvaluationDashboardCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationDashboard,
        )

    async def retrieve(
        self,
        dashboard_id: str,
        *,
        include_archived: bool | Omit = omit,
        views: List[Literal["widgets", "widget_results"]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluationDashboard:
        """
        Get a single evaluation dashboard by ID

        Args:
          views: Optional relationships to include: 'widgets', 'widget_results'

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dashboard_id:
            raise ValueError(f"Expected a non-empty value for `dashboard_id` but received {dashboard_id!r}")
        return await self._get(
            f"/v5/evaluation-dashboards/{dashboard_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "include_archived": include_archived,
                        "views": views,
                    },
                    evaluation_dashboard_retrieve_params.EvaluationDashboardRetrieveParams,
                ),
            ),
            cast_to=EvaluationDashboard,
        )

    async def update(
        self,
        dashboard_id: str,
        *,
        description: str | Omit = omit,
        name: str | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        widget_order: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluationDashboard:
        """
        Partially update dashboard metadata (name, description, widget_order)

        Args:
          description: Dashboard description

          name: Dashboard name

          tags: The tags associated with the entity

          widget_order: Ordered array of widget IDs (for reordering widgets)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dashboard_id:
            raise ValueError(f"Expected a non-empty value for `dashboard_id` but received {dashboard_id!r}")
        return await self._patch(
            f"/v5/evaluation-dashboards/{dashboard_id}",
            body=await async_maybe_transform(
                {
                    "description": description,
                    "name": name,
                    "tags": tags,
                    "widget_order": widget_order,
                },
                evaluation_dashboard_update_params.EvaluationDashboardUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationDashboard,
        )

    def list(
        self,
        *,
        created_by_ids: SequenceNotStr[str] | Omit = omit,
        ending_before: str | Omit = omit,
        evaluation_group_id: str | Omit = omit,
        evaluation_id: str | Omit = omit,
        include_archived: bool | Omit = omit,
        limit: int | Omit = omit,
        search: str | Omit = omit,
        sort_by: str | Omit = omit,
        sort_order: Literal["asc", "desc"] | Omit = omit,
        starting_after: str | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[EvaluationDashboard, AsyncCursorPage[EvaluationDashboard]]:
        """
        List dashboards filtered by evaluation_id, evaluation_group_id, tags, creators,
        or search

        Args:
          created_by_ids: Filter by creator user IDs

          search: Search in name and tags

          tags: Filter by tags (case-insensitive)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v5/evaluation-dashboards",
            page=AsyncCursorPage[EvaluationDashboard],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "created_by_ids": created_by_ids,
                        "ending_before": ending_before,
                        "evaluation_group_id": evaluation_group_id,
                        "evaluation_id": evaluation_id,
                        "include_archived": include_archived,
                        "limit": limit,
                        "search": search,
                        "sort_by": sort_by,
                        "sort_order": sort_order,
                        "starting_after": starting_after,
                        "tags": tags,
                    },
                    evaluation_dashboard_list_params.EvaluationDashboardListParams,
                ),
            ),
            model=EvaluationDashboard,
        )

    async def delete(
        self,
        dashboard_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluationDashboard:
        """
        Soft delete an evaluation dashboard

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dashboard_id:
            raise ValueError(f"Expected a non-empty value for `dashboard_id` but received {dashboard_id!r}")
        return await self._delete(
            f"/v5/evaluation-dashboards/{dashboard_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationDashboard,
        )


class EvaluationDashboardsResourceWithRawResponse:
    def __init__(self, evaluation_dashboards: EvaluationDashboardsResource) -> None:
        self._evaluation_dashboards = evaluation_dashboards

        self.create = to_raw_response_wrapper(
            evaluation_dashboards.create,
        )
        self.retrieve = to_raw_response_wrapper(
            evaluation_dashboards.retrieve,
        )
        self.update = to_raw_response_wrapper(
            evaluation_dashboards.update,
        )
        self.list = to_raw_response_wrapper(
            evaluation_dashboards.list,
        )
        self.delete = to_raw_response_wrapper(
            evaluation_dashboards.delete,
        )

    @cached_property
    def widgets(self) -> WidgetsResourceWithRawResponse:
        return WidgetsResourceWithRawResponse(self._evaluation_dashboards.widgets)


class AsyncEvaluationDashboardsResourceWithRawResponse:
    def __init__(self, evaluation_dashboards: AsyncEvaluationDashboardsResource) -> None:
        self._evaluation_dashboards = evaluation_dashboards

        self.create = async_to_raw_response_wrapper(
            evaluation_dashboards.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            evaluation_dashboards.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            evaluation_dashboards.update,
        )
        self.list = async_to_raw_response_wrapper(
            evaluation_dashboards.list,
        )
        self.delete = async_to_raw_response_wrapper(
            evaluation_dashboards.delete,
        )

    @cached_property
    def widgets(self) -> AsyncWidgetsResourceWithRawResponse:
        return AsyncWidgetsResourceWithRawResponse(self._evaluation_dashboards.widgets)


class EvaluationDashboardsResourceWithStreamingResponse:
    def __init__(self, evaluation_dashboards: EvaluationDashboardsResource) -> None:
        self._evaluation_dashboards = evaluation_dashboards

        self.create = to_streamed_response_wrapper(
            evaluation_dashboards.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            evaluation_dashboards.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            evaluation_dashboards.update,
        )
        self.list = to_streamed_response_wrapper(
            evaluation_dashboards.list,
        )
        self.delete = to_streamed_response_wrapper(
            evaluation_dashboards.delete,
        )

    @cached_property
    def widgets(self) -> WidgetsResourceWithStreamingResponse:
        return WidgetsResourceWithStreamingResponse(self._evaluation_dashboards.widgets)


class AsyncEvaluationDashboardsResourceWithStreamingResponse:
    def __init__(self, evaluation_dashboards: AsyncEvaluationDashboardsResource) -> None:
        self._evaluation_dashboards = evaluation_dashboards

        self.create = async_to_streamed_response_wrapper(
            evaluation_dashboards.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            evaluation_dashboards.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            evaluation_dashboards.update,
        )
        self.list = async_to_streamed_response_wrapper(
            evaluation_dashboards.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            evaluation_dashboards.delete,
        )

    @cached_property
    def widgets(self) -> AsyncWidgetsResourceWithStreamingResponse:
        return AsyncWidgetsResourceWithStreamingResponse(self._evaluation_dashboards.widgets)



# type: ignore
import json
from typing import Any, Dict, Optional

try:
    from agents.tracing import (
        Span as OpenAISpan,
        ResponseSpanData as OpenAIResponseSpanData,
    )
except ImportError:
    OpenAISpan = Any
    OpenAIResponseSpanData = Any


def sgp_span_name(openai_span: "OpenAISpan") -> str:
    span_data = openai_span.span_data
    if span_data is None:
        return "Unnamed Span"
    default_name = str(type(span_data).__name__).replace("SpanData", "")

    return span_data.export().get("name", default_name)


def extract_response(openai_span: "OpenAISpan") -> Optional[Dict[str, Any]]:
    span_data = openai_span.span_data
    if not isinstance(span_data, OpenAIResponseSpanData):
        return None

    return {} if span_data.response is None else span_data.response.model_dump()


def parse_metadata(openai_span: "OpenAISpan") -> Dict[str, Any]:
    """Extracts and formats metadata from an OpenAI span."""
    if not openai_span.span_data:
        return {}

    excluded_fields = ("output", "input")
    exported_span_data: dict = openai_span.span_data.export()
    exported_span_data["openai_span_id"] = openai_span.span_id

    filtered_span_data: dict = {
        k: v for k, v in exported_span_data.items() if k not in excluded_fields
    }
    response = extract_response(openai_span)
    if response is not None:
        filtered_span_data["openai_response"] = response
    return {"openai_metadata": filtered_span_data}


def parse_input_output(openai_span: "OpenAISpan", key: str) -> Dict[str, Any]:
    """
    Safely extracts and parses input/output data from a span.
    The openai-agents SDK sometimes returns this data as a JSON string.
    """
    span_data = openai_span.span_data
    if not span_data:
        return {}
    exported_span_data: dict = span_data.export()
    value: Optional[Any] = exported_span_data.get(key)
    if value is None:
        return {}

    if isinstance(value, str):
        try:
            value = json.loads(value)
            if isinstance(value, dict):
                return value
        except (json.JSONDecodeError, TypeError):
            return {key: value}
    return {key: value}



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .span import Span
from .._models import BaseModel

__all__ = ["SpanUpsertBatchResponse"]


class SpanUpsertBatchResponse(BaseModel):
    items: List[Span]

    object: Optional[Literal["list"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable
from typing_extensions import Literal

import httpx

from ..types import (
    dataset_item_list_params,
    dataset_item_update_params,
    dataset_item_retrieve_params,
    dataset_item_batch_create_params,
)
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..pagination import SyncCursorPage, AsyncCursorPage
from .._base_client import AsyncPaginator, make_request_options
from ..types.dataset_item import DatasetItem
from ..types.dataset_item_delete_response import DatasetItemDeleteResponse
from ..types.dataset_item_batch_create_response import DatasetItemBatchCreateResponse

__all__ = ["DatasetItemsResource", "AsyncDatasetItemsResource"]


class DatasetItemsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> DatasetItemsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#accessing-raw-response-data-eg-headers
        """
        return DatasetItemsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DatasetItemsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#with_streaming_response
        """
        return DatasetItemsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        dataset_item_id: str,
        *,
        version: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DatasetItem:
        """Get Dataset Item

        Args:
          version: Optional dataset version.

        When unset, returns the latest version.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dataset_item_id:
            raise ValueError(f"Expected a non-empty value for `dataset_item_id` but received {dataset_item_id!r}")
        return self._get(
            f"/v5/dataset-items/{dataset_item_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"version": version}, dataset_item_retrieve_params.DatasetItemRetrieveParams),
            ),
            cast_to=DatasetItem,
        )

    def update(
        self,
        dataset_item_id: str,
        *,
        data: Dict[str, object],
        files: Dict[str, str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DatasetItem:
        """
        Update Dataset Item

        Args:
          data: Updated dataset item data

          files: Files to be associated to the dataset

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dataset_item_id:
            raise ValueError(f"Expected a non-empty value for `dataset_item_id` but received {dataset_item_id!r}")
        return self._patch(
            f"/v5/dataset-items/{dataset_item_id}",
            body=maybe_transform(
                {
                    "data": data,
                    "files": files,
                },
                dataset_item_update_params.DatasetItemUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasetItem,
        )

    def list(
        self,
        *,
        dataset_id: str | Omit = omit,
        ending_before: str | Omit = omit,
        include_archived: bool | Omit = omit,
        limit: int | Omit = omit,
        sort_by: str | Omit = omit,
        sort_order: Literal["asc", "desc"] | Omit = omit,
        starting_after: str | Omit = omit,
        version: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncCursorPage[DatasetItem]:
        """List Dataset Items

        Args:
          dataset_id: Optional dataset identifier.

        Must be provided if a specific version is
              requested.

          version: Optional dataset version. When unset, returns the latest version. Requires a
              valid dataset_id when set.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v5/dataset-items",
            page=SyncCursorPage[DatasetItem],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "dataset_id": dataset_id,
                        "ending_before": ending_before,
                        "include_archived": include_archived,
                        "limit": limit,
                        "sort_by": sort_by,
                        "sort_order": sort_order,
                        "starting_after": starting_after,
                        "version": version,
                    },
                    dataset_item_list_params.DatasetItemListParams,
                ),
            ),
            model=DatasetItem,
        )

    def delete(
        self,
        dataset_item_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DatasetItemDeleteResponse:
        """
        Delete Dataset Item

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dataset_item_id:
            raise ValueError(f"Expected a non-empty value for `dataset_item_id` but received {dataset_item_id!r}")
        return self._delete(
            f"/v5/dataset-items/{dataset_item_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasetItemDeleteResponse,
        )

    def batch_create(
        self,
        *,
        data: Iterable[Dict[str, object]],
        dataset_id: str,
        files: Iterable[Dict[str, str]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DatasetItemBatchCreateResponse:
        """
        Batch Create Dataset Items

        Args:
          data: Items to be added to the dataset

          dataset_id: Identifier of the target dataset

          files: Files to be associated to the dataset

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v5/dataset-items/batch",
            body=maybe_transform(
                {
                    "data": data,
                    "dataset_id": dataset_id,
                    "files": files,
                },
                dataset_item_batch_create_params.DatasetItemBatchCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasetItemBatchCreateResponse,
        )


class AsyncDatasetItemsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncDatasetItemsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#accessing-raw-response-data-eg-headers
        """
        return AsyncDatasetItemsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDatasetItemsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#with_streaming_response
        """
        return AsyncDatasetItemsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        dataset_item_id: str,
        *,
        version: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DatasetItem:
        """Get Dataset Item

        Args:
          version: Optional dataset version.

        When unset, returns the latest version.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dataset_item_id:
            raise ValueError(f"Expected a non-empty value for `dataset_item_id` but received {dataset_item_id!r}")
        return await self._get(
            f"/v5/dataset-items/{dataset_item_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"version": version}, dataset_item_retrieve_params.DatasetItemRetrieveParams
                ),
            ),
            cast_to=DatasetItem,
        )

    async def update(
        self,
        dataset_item_id: str,
        *,
        data: Dict[str, object],
        files: Dict[str, str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DatasetItem:
        """
        Update Dataset Item

        Args:
          data: Updated dataset item data

          files: Files to be associated to the dataset

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dataset_item_id:
            raise ValueError(f"Expected a non-empty value for `dataset_item_id` but received {dataset_item_id!r}")
        return await self._patch(
            f"/v5/dataset-items/{dataset_item_id}",
            body=await async_maybe_transform(
                {
                    "data": data,
                    "files": files,
                },
                dataset_item_update_params.DatasetItemUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasetItem,
        )

    def list(
        self,
        *,
        dataset_id: str | Omit = omit,
        ending_before: str | Omit = omit,
        include_archived: bool | Omit = omit,
        limit: int | Omit = omit,
        sort_by: str | Omit = omit,
        sort_order: Literal["asc", "desc"] | Omit = omit,
        starting_after: str | Omit = omit,
        version: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[DatasetItem, AsyncCursorPage[DatasetItem]]:
        """List Dataset Items

        Args:
          dataset_id: Optional dataset identifier.

        Must be provided if a specific version is
              requested.

          version: Optional dataset version. When unset, returns the latest version. Requires a
              valid dataset_id when set.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v5/dataset-items",
            page=AsyncCursorPage[DatasetItem],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "dataset_id": dataset_id,
                        "ending_before": ending_before,
                        "include_archived": include_archived,
                        "limit": limit,
                        "sort_by": sort_by,
                        "sort_order": sort_order,
                        "starting_after": starting_after,
                        "version": version,
                    },
                    dataset_item_list_params.DatasetItemListParams,
                ),
            ),
            model=DatasetItem,
        )

    async def delete(
        self,
        dataset_item_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DatasetItemDeleteResponse:
        """
        Delete Dataset Item

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dataset_item_id:
            raise ValueError(f"Expected a non-empty value for `dataset_item_id` but received {dataset_item_id!r}")
        return await self._delete(
            f"/v5/dataset-items/{dataset_item_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasetItemDeleteResponse,
        )

    async def batch_create(
        self,
        *,
        data: Iterable[Dict[str, object]],
        dataset_id: str,
        files: Iterable[Dict[str, str]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DatasetItemBatchCreateResponse:
        """
        Batch Create Dataset Items

        Args:
          data: Items to be added to the dataset

          dataset_id: Identifier of the target dataset

          files: Files to be associated to the dataset

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v5/dataset-items/batch",
            body=await async_maybe_transform(
                {
                    "data": data,
                    "dataset_id": dataset_id,
                    "files": files,
                },
                dataset_item_batch_create_params.DatasetItemBatchCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasetItemBatchCreateResponse,
        )


class DatasetItemsResourceWithRawResponse:
    def __init__(self, dataset_items: DatasetItemsResource) -> None:
        self._dataset_items = dataset_items

        self.retrieve = to_raw_response_wrapper(
            dataset_items.retrieve,
        )
        self.update = to_raw_response_wrapper(
            dataset_items.update,
        )
        self.list = to_raw_response_wrapper(
            dataset_items.list,
        )
        self.delete = to_raw_response_wrapper(
            dataset_items.delete,
        )
        self.batch_create = to_raw_response_wrapper(
            dataset_items.batch_create,
        )


class AsyncDatasetItemsResourceWithRawResponse:
    def __init__(self, dataset_items: AsyncDatasetItemsResource) -> None:
        self._dataset_items = dataset_items

        self.retrieve = async_to_raw_response_wrapper(
            dataset_items.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            dataset_items.update,
        )
        self.list = async_to_raw_response_wrapper(
            dataset_items.list,
        )
        self.delete = async_to_raw_response_wrapper(
            dataset_items.delete,
        )
        self.batch_create = async_to_raw_response_wrapper(
            dataset_items.batch_create,
        )


class DatasetItemsResourceWithStreamingResponse:
    def __init__(self, dataset_items: DatasetItemsResource) -> None:
        self._dataset_items = dataset_items

        self.retrieve = to_streamed_response_wrapper(
            dataset_items.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            dataset_items.update,
        )
        self.list = to_streamed_response_wrapper(
            dataset_items.list,
        )
        self.delete = to_streamed_response_wrapper(
            dataset_items.delete,
        )
        self.batch_create = to_streamed_response_wrapper(
            dataset_items.batch_create,
        )


class AsyncDatasetItemsResourceWithStreamingResponse:
    def __init__(self, dataset_items: AsyncDatasetItemsResource) -> None:
        self._dataset_items = dataset_items

        self.retrieve = async_to_streamed_response_wrapper(
            dataset_items.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            dataset_items.update,
        )
        self.list = async_to_streamed_response_wrapper(
            dataset_items.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            dataset_items.delete,
        )
        self.batch_create = async_to_streamed_response_wrapper(
            dataset_items.batch_create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Mapping, Iterable, cast
from typing_extensions import Literal

import httpx

from ...types import file_list_params, file_create_params, file_update_params, file_import_from_cloud_params
from .content import (
    ContentResource,
    AsyncContentResource,
    ContentResourceWithRawResponse,
    AsyncContentResourceWithRawResponse,
    ContentResourceWithStreamingResponse,
    AsyncContentResourceWithStreamingResponse,
)
from ..._types import Body, Omit, Query, Headers, NotGiven, FileTypes, omit, not_given
from ..._utils import extract_files, maybe_transform, deepcopy_minimal, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...pagination import SyncCursorPage, AsyncCursorPage
from ...types.file import File
from ..._base_client import AsyncPaginator, make_request_options
from ...types.file_delete_response import FileDeleteResponse
from ...types.file_import_from_cloud_response import FileImportFromCloudResponse

__all__ = ["FilesResource", "AsyncFilesResource"]


class FilesResource(SyncAPIResource):
    @cached_property
    def content(self) -> ContentResource:
        return ContentResource(self._client)

    @cached_property
    def with_raw_response(self) -> FilesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#accessing-raw-response-data-eg-headers
        """
        return FilesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> FilesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#with_streaming_response
        """
        return FilesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        file: FileTypes,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> File:
        """
        Upload File

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        body = deepcopy_minimal({"file": file})
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return self._post(
            "/v5/files",
            body=maybe_transform(body, file_create_params.FileCreateParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=File,
        )

    def retrieve(
        self,
        file_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> File:
        """
        Get File

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        return self._get(
            f"/v5/files/{file_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=File,
        )

    def update(
        self,
        file_id: str,
        *,
        tags: Dict[str, object] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> File:
        """
        Update File

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        return self._patch(
            f"/v5/files/{file_id}",
            body=maybe_transform({"tags": tags}, file_update_params.FileUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=File,
        )

    def list(
        self,
        *,
        ending_before: str | Omit = omit,
        filename: str | Omit = omit,
        limit: int | Omit = omit,
        sort_by: str | Omit = omit,
        sort_order: Literal["asc", "desc"] | Omit = omit,
        starting_after: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncCursorPage[File]:
        """
        List Files

        Args:
          filename: Filter files by filename (case-insensitive partial match)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v5/files",
            page=SyncCursorPage[File],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "ending_before": ending_before,
                        "filename": filename,
                        "limit": limit,
                        "sort_by": sort_by,
                        "sort_order": sort_order,
                        "starting_after": starting_after,
                    },
                    file_list_params.FileListParams,
                ),
            ),
            model=File,
        )

    def delete(
        self,
        file_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> FileDeleteResponse:
        """
        Delete File

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        return self._delete(
            f"/v5/files/{file_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FileDeleteResponse,
        )

    def import_from_cloud(
        self,
        *,
        files: Iterable[file_import_from_cloud_params.File],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> FileImportFromCloudResponse:
        """
        Import files from existing blob storage in cloud (batch operation)

        Args:
          files: List of files to import from cloud storage

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v5/files/cloud_imports",
            body=maybe_transform({"files": files}, file_import_from_cloud_params.FileImportFromCloudParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FileImportFromCloudResponse,
        )


class AsyncFilesResource(AsyncAPIResource):
    @cached_property
    def content(self) -> AsyncContentResource:
        return AsyncContentResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncFilesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#accessing-raw-response-data-eg-headers
        """
        return AsyncFilesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncFilesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#with_streaming_response
        """
        return AsyncFilesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        file: FileTypes,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> File:
        """
        Upload File

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        body = deepcopy_minimal({"file": file})
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return await self._post(
            "/v5/files",
            body=await async_maybe_transform(body, file_create_params.FileCreateParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=File,
        )

    async def retrieve(
        self,
        file_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> File:
        """
        Get File

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        return await self._get(
            f"/v5/files/{file_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=File,
        )

    async def update(
        self,
        file_id: str,
        *,
        tags: Dict[str, object] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> File:
        """
        Update File

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        return await self._patch(
            f"/v5/files/{file_id}",
            body=await async_maybe_transform({"tags": tags}, file_update_params.FileUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=File,
        )

    def list(
        self,
        *,
        ending_before: str | Omit = omit,
        filename: str | Omit = omit,
        limit: int | Omit = omit,
        sort_by: str | Omit = omit,
        sort_order: Literal["asc", "desc"] | Omit = omit,
        starting_after: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[File, AsyncCursorPage[File]]:
        """
        List Files

        Args:
          filename: Filter files by filename (case-insensitive partial match)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v5/files",
            page=AsyncCursorPage[File],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "ending_before": ending_before,
                        "filename": filename,
                        "limit": limit,
                        "sort_by": sort_by,
                        "sort_order": sort_order,
                        "starting_after": starting_after,
                    },
                    file_list_params.FileListParams,
                ),
            ),
            model=File,
        )

    async def delete(
        self,
        file_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> FileDeleteResponse:
        """
        Delete File

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        return await self._delete(
            f"/v5/files/{file_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FileDeleteResponse,
        )

    async def import_from_cloud(
        self,
        *,
        files: Iterable[file_import_from_cloud_params.File],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> FileImportFromCloudResponse:
        """
        Import files from existing blob storage in cloud (batch operation)

        Args:
          files: List of files to import from cloud storage

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v5/files/cloud_imports",
            body=await async_maybe_transform({"files": files}, file_import_from_cloud_params.FileImportFromCloudParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FileImportFromCloudResponse,
        )


class FilesResourceWithRawResponse:
    def __init__(self, files: FilesResource) -> None:
        self._files = files

        self.create = to_raw_response_wrapper(
            files.create,
        )
        self.retrieve = to_raw_response_wrapper(
            files.retrieve,
        )
        self.update = to_raw_response_wrapper(
            files.update,
        )
        self.list = to_raw_response_wrapper(
            files.list,
        )
        self.delete = to_raw_response_wrapper(
            files.delete,
        )
        self.import_from_cloud = to_raw_response_wrapper(
            files.import_from_cloud,
        )

    @cached_property
    def content(self) -> ContentResourceWithRawResponse:
        return ContentResourceWithRawResponse(self._files.content)


class AsyncFilesResourceWithRawResponse:
    def __init__(self, files: AsyncFilesResource) -> None:
        self._files = files

        self.create = async_to_raw_response_wrapper(
            files.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            files.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            files.update,
        )
        self.list = async_to_raw_response_wrapper(
            files.list,
        )
        self.delete = async_to_raw_response_wrapper(
            files.delete,
        )
        self.import_from_cloud = async_to_raw_response_wrapper(
            files.import_from_cloud,
        )

    @cached_property
    def content(self) -> AsyncContentResourceWithRawResponse:
        return AsyncContentResourceWithRawResponse(self._files.content)


class FilesResourceWithStreamingResponse:
    def __init__(self, files: FilesResource) -> None:
        self._files = files

        self.create = to_streamed_response_wrapper(
            files.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            files.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            files.update,
        )
        self.list = to_streamed_response_wrapper(
            files.list,
        )
        self.delete = to_streamed_response_wrapper(
            files.delete,
        )
        self.import_from_cloud = to_streamed_response_wrapper(
            files.import_from_cloud,
        )

    @cached_property
    def content(self) -> ContentResourceWithStreamingResponse:
        return ContentResourceWithStreamingResponse(self._files.content)


class AsyncFilesResourceWithStreamingResponse:
    def __init__(self, files: AsyncFilesResource) -> None:
        self._files = files

        self.create = async_to_streamed_response_wrapper(
            files.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            files.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            files.update,
        )
        self.list = async_to_streamed_response_wrapper(
            files.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            files.delete,
        )
        self.import_from_cloud = async_to_streamed_response_wrapper(
            files.import_from_cloud,
        )

    @cached_property
    def content(self) -> AsyncContentResourceWithStreamingResponse:
        return AsyncContentResourceWithStreamingResponse(self._files.content)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union, Iterable
from datetime import datetime
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo
from .span_type import SpanType
from .span_status import SpanStatus

__all__ = ["SpanBatchParams", "Item"]


class SpanBatchParams(TypedDict, total=False):
    items: Required[Iterable[Item]]


class Item(TypedDict, total=False):
    name: Required[str]

    start_timestamp: Required[Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]]

    trace_id: Required[str]
    """id for grouping traces together, uuid is recommended"""

    id: str
    """The id of the span"""

    application_interaction_id: str
    """The optional application interaction ID this span belongs to"""

    application_variant_id: str
    """The optional application variant ID this span belongs to"""

    end_timestamp: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]

    group_id: str
    """Reference to a group_id"""

    input: Dict[str, object]

    metadata: Dict[str, object]

    output: Dict[str, object]

    parent_id: str
    """Reference to a parent span_id"""

    status: SpanStatus

    type: SpanType



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable
from typing_extensions import Literal, overload

import httpx

from ..types import dataset_list_params, dataset_create_params, dataset_update_params, dataset_retrieve_params
from .._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..pagination import SyncCursorPage, AsyncCursorPage
from .._base_client import AsyncPaginator, make_request_options
from ..types.dataset import Dataset
from ..types.dataset_delete_response import DatasetDeleteResponse

__all__ = ["DatasetsResource", "AsyncDatasetsResource"]


class DatasetsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> DatasetsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#accessing-raw-response-data-eg-headers
        """
        return DatasetsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DatasetsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#with_streaming_response
        """
        return DatasetsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        data: Iterable[Dict[str, object]],
        name: str,
        description: str | Omit = omit,
        files: Iterable[Dict[str, str]] | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Dataset:
        """
        Create Dataset

        Args:
          data: Items to be included in the dataset

          files: Files to be associated to the dataset

          tags: The tags associated with the entity

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v5/datasets",
            body=maybe_transform(
                {
                    "data": data,
                    "name": name,
                    "description": description,
                    "files": files,
                    "tags": tags,
                },
                dataset_create_params.DatasetCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Dataset,
        )

    def retrieve(
        self,
        dataset_id: str,
        *,
        include_archived: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Dataset:
        """
        Get Dataset

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dataset_id:
            raise ValueError(f"Expected a non-empty value for `dataset_id` but received {dataset_id!r}")
        return self._get(
            f"/v5/datasets/{dataset_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"include_archived": include_archived}, dataset_retrieve_params.DatasetRetrieveParams
                ),
            ),
            cast_to=Dataset,
        )

    @overload
    def update(
        self,
        dataset_id: str,
        *,
        description: str | Omit = omit,
        name: str | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Dataset:
        """
        Update or Restore Dataset

        Args:
          tags: The tags associated with the entity

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dataset_id: str,
        *,
        restore: Literal[True],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Dataset:
        """
        Update or Restore Dataset

        Args:
          restore: Set to true to restore the entity from the database.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    def update(
        self,
        dataset_id: str,
        *,
        description: str | Omit = omit,
        name: str | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        restore: Literal[True] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Dataset:
        if not dataset_id:
            raise ValueError(f"Expected a non-empty value for `dataset_id` but received {dataset_id!r}")
        return self._patch(
            f"/v5/datasets/{dataset_id}",
            body=maybe_transform(
                {
                    "description": description,
                    "name": name,
                    "tags": tags,
                    "restore": restore,
                },
                dataset_update_params.DatasetUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Dataset,
        )

    def list(
        self,
        *,
        ending_before: str | Omit = omit,
        include_archived: bool | Omit = omit,
        limit: int | Omit = omit,
        name: str | Omit = omit,
        sort_by: str | Omit = omit,
        sort_order: Literal["asc", "desc"] | Omit = omit,
        starting_after: str | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncCursorPage[Dataset]:
        """
        List Datasets

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v5/datasets",
            page=SyncCursorPage[Dataset],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "ending_before": ending_before,
                        "include_archived": include_archived,
                        "limit": limit,
                        "name": name,
                        "sort_by": sort_by,
                        "sort_order": sort_order,
                        "starting_after": starting_after,
                        "tags": tags,
                    },
                    dataset_list_params.DatasetListParams,
                ),
            ),
            model=Dataset,
        )

    def delete(
        self,
        dataset_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DatasetDeleteResponse:
        """
        Delete Dataset

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dataset_id:
            raise ValueError(f"Expected a non-empty value for `dataset_id` but received {dataset_id!r}")
        return self._delete(
            f"/v5/datasets/{dataset_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasetDeleteResponse,
        )


class AsyncDatasetsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncDatasetsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#accessing-raw-response-data-eg-headers
        """
        return AsyncDatasetsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDatasetsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/scaleapi/sgp-python-beta#with_streaming_response
        """
        return AsyncDatasetsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        data: Iterable[Dict[str, object]],
        name: str,
        description: str | Omit = omit,
        files: Iterable[Dict[str, str]] | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Dataset:
        """
        Create Dataset

        Args:
          data: Items to be included in the dataset

          files: Files to be associated to the dataset

          tags: The tags associated with the entity

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v5/datasets",
            body=await async_maybe_transform(
                {
                    "data": data,
                    "name": name,
                    "description": description,
                    "files": files,
                    "tags": tags,
                },
                dataset_create_params.DatasetCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Dataset,
        )

    async def retrieve(
        self,
        dataset_id: str,
        *,
        include_archived: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Dataset:
        """
        Get Dataset

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dataset_id:
            raise ValueError(f"Expected a non-empty value for `dataset_id` but received {dataset_id!r}")
        return await self._get(
            f"/v5/datasets/{dataset_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"include_archived": include_archived}, dataset_retrieve_params.DatasetRetrieveParams
                ),
            ),
            cast_to=Dataset,
        )

    @overload
    async def update(
        self,
        dataset_id: str,
        *,
        description: str | Omit = omit,
        name: str | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Dataset:
        """
        Update or Restore Dataset

        Args:
          tags: The tags associated with the entity

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dataset_id: str,
        *,
        restore: Literal[True],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Dataset:
        """
        Update or Restore Dataset

        Args:
          restore: Set to true to restore the entity from the database.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    async def update(
        self,
        dataset_id: str,
        *,
        description: str | Omit = omit,
        name: str | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        restore: Literal[True] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Dataset:
        if not dataset_id:
            raise ValueError(f"Expected a non-empty value for `dataset_id` but received {dataset_id!r}")
        return await self._patch(
            f"/v5/datasets/{dataset_id}",
            body=await async_maybe_transform(
                {
                    "description": description,
                    "name": name,
                    "tags": tags,
                    "restore": restore,
                },
                dataset_update_params.DatasetUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Dataset,
        )

    def list(
        self,
        *,
        ending_before: str | Omit = omit,
        include_archived: bool | Omit = omit,
        limit: int | Omit = omit,
        name: str | Omit = omit,
        sort_by: str | Omit = omit,
        sort_order: Literal["asc", "desc"] | Omit = omit,
        starting_after: str | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[Dataset, AsyncCursorPage[Dataset]]:
        """
        List Datasets

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v5/datasets",
            page=AsyncCursorPage[Dataset],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "ending_before": ending_before,
                        "include_archived": include_archived,
                        "limit": limit,
                        "name": name,
                        "sort_by": sort_by,
                        "sort_order": sort_order,
                        "starting_after": starting_after,
                        "tags": tags,
                    },
                    dataset_list_params.DatasetListParams,
                ),
            ),
            model=Dataset,
        )

    async def delete(
        self,
        dataset_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DatasetDeleteResponse:
        """
        Delete Dataset

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not dataset_id:
            raise ValueError(f"Expected a non-empty value for `dataset_id` but received {dataset_id!r}")
        return await self._delete(
            f"/v5/datasets/{dataset_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasetDeleteResponse,
        )


class DatasetsResourceWithRawResponse:
    def __init__(self, datasets: DatasetsResource) -> None:
        self._datasets = datasets

        self.create = to_raw_response_wrapper(
            datasets.create,
        )
        self.retrieve = to_raw_response_wrapper(
            datasets.retrieve,
        )
        self.update = to_raw_response_wrapper(
            datasets.update,
        )
        self.list = to_raw_response_wrapper(
            datasets.list,
        )
        self.delete = to_raw_response_wrapper(
            datasets.delete,
        )


class AsyncDatasetsResourceWithRawResponse:
    def __init__(self, datasets: AsyncDatasetsResource) -> None:
        self._datasets = datasets

        self.create = async_to_raw_response_wrapper(
            datasets.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            datasets.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            datasets.update,
        )
        self.list = async_to_raw_response_wrapper(
            datasets.list,
        )
        self.delete = async_to_raw_response_wrapper(
            datasets.delete,
        )


class DatasetsResourceWithStreamingResponse:
    def __init__(self, datasets: DatasetsResource) -> None:
        self._datasets = datasets

        self.create = to_streamed_response_wrapper(
            datasets.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            datasets.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            datasets.update,
        )
        self.list = to_streamed_response_wrapper(
            datasets.list,
        )
        self.delete = to_streamed_response_wrapper(
            datasets.delete,
        )


class AsyncDatasetsResourceWithStreamingResponse:
    def __init__(self, datasets: AsyncDatasetsResource) -> None:
        self._datasets = datasets

        self.create = async_to_streamed_response_wrapper(
            datasets.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            datasets.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            datasets.update,
        )
        self.list = async_to_streamed_response_wrapper(
            datasets.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            datasets.delete,
        )



from .tracing import create_span, flush_queue, create_trace, current_span, current_trace
from .trace_queue_manager import init

__all__ = ["init", "create_span", "create_trace", "current_trace", "current_span", "flush_queue"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import builtins
from typing import Dict, Optional
from datetime import datetime
from typing_extensions import Literal

from .._models import BaseModel
from .shared.identity import Identity

__all__ = ["File"]


class File(BaseModel):
    id: str

    created_at: datetime

    created_by: Identity
    """The identity that created the entity."""

    filename: str

    md5_checksum: str

    mime_type: str

    size: int

    duration_seconds: Optional[int] = None

    object: Optional[Literal["file"]] = None

    tags: Optional[Dict[str, builtins.object]] = None
